@@ -12,6 +12,7 @@ try:
     from paved.util import *
     from paved.docs import *
     from paved.pycheck import *
+    from paved.pkg import *
     from sphinxcontrib import paverutils
     ALL_TASKS_LOADED = True
 except ImportError, e:
@@ -46,15 +47,7 @@ classifiers = [
     "Programming Language :: Python",
     ]
 
-install_requires = [
-    # -*- Install requires: -*-
-    'setuptools',
-    'yapsy',
-    'path.py',
-    'argparse',
-    'EasyProcess',
-    'entrypoint2',
-    ]
+install_requires = open("requirements.txt").read().split('\n')
 
 # compatible with distutils of python 2.3+ or later
 setup(
@@ -100,10 +93,19 @@ if ALL_TASKS_LOADED:
     
     options.paved.dist.manifest.include.remove('distribute_setup.py')
     options.paved.dist.manifest.recursive_include.add('psidialogs *.conf')
+    options.paved.dist.manifest.include.add('requirements.txt')
     
     
     @task
-    @needs('sloccount', 'cog', 'html', 'pdf', 'sdist', 'nose')
+    @needs(
+           'clean',
+           'sloccount', 
+           'cog', 
+           'html', 
+           'pdf', 
+           'sdist', 
+           'nose',
+           )
     def alltest():
         'all tasks to check'
         pass
