@@ -1,3 +1,4 @@
+from psidialogs.unicodeutil import uniencode, unidecode
 from yapsy.IPlugin import IPlugin
 
 class Backend(IPlugin):
@@ -6,14 +7,17 @@ class Backend(IPlugin):
     #backend_version
     
     def message(self, args):
-        msg=args.message+'[ENTER]'
-        print raw_input(msg)
+        msg = args.message + '[ENTER]'
+        msg = uniencode(msg)
+        raw_input(msg)
         
     def ask_string(self, args):
-        return raw_input(args.message)
-        
+        answer = raw_input(uniencode(args.message))
+        return unidecode(answer)
+    
     def ask_yes_no(self, args):
         msg = args.message
+        msg = uniencode(msg)
         msg += ' [Yes/No] '
         answers_yes = 'yes y'.split()
         answers_no = 'no n'.split()
@@ -21,6 +25,7 @@ class Backend(IPlugin):
         s = ''
         while 1:
             s = raw_input(msg)
+            s = unidecode(s)
             s = s.lower().strip()
             if s in answers:
                 break
@@ -33,9 +38,9 @@ class Backend(IPlugin):
         return self.ask_yes_no(args)
     
     def warning(self, args):
-        args.message='[WARNING] '+args.message
+        args.message = '[WARNING] ' + args.message
         return self.message(args)
 
     def error(self, args):
-        args.message='[ERROR] '+args.message
+        args.message = '[ERROR] ' + args.message
         return self.message(args)
